#!/bin/bash


. ../environment_tpw.job

echo $PWDIR
THERMO_PW_COMMAND="$PREFIX $PWDIR/thermo_pw.x $SUFFIX"

NAME="si"
ECHO="echo"

mkdir results
cd results

#thermo_pw commands
cat > thermo_control << EOF
 &INPUT_THERMO
  what='mur_lc_disp',
  nq1_d=128, nq2_d=128, nq3_d=128,
 /
EOF
 
# self-consistent calculation
cat > $NAME.scf.in << EOF
 &control
    calculation='scf'
    prefix='$NAME',
    pseudo_dir = '$PSEUDODIR/',
    outdir='$TMPDIR/'
 /
 &system    
    ibrav=  2, 
    celldm(1) =10.20, 
    nat=  2, 
    ntyp= 1,
    ecutwfc =$ECUTWFC
 /
 &electrons
    conv_thr =  1.0d-10
 /
ATOMIC_SPECIES
 Si  0.0  Si.pz-vbc.UPF
ATOMIC_POSITIONS
 Si 0.00 0.00 0.00 
 Si 0.25 0.25 0.25 
K_POINTS AUTOMATIC
4 4 4 1 1 1
EOF

# phonons
cat > ph_control << EOF
phonons at Gamma
 &inputph
   prefix='$NAME',
   ldisp=.true.
   fildyn='si.dyn.xml',
   nq1=4,
   nq2=4,
   nq3=4,
   tr2_ph=1.0d-16,
 /
EOF

$ECHO "  running the phonon calculation on a 4x4x4 mesh..."
$THERMO_PW_COMMAND < $NAME.scf.in > $NAME.scf.out

cd ..
